ATel #1: QPOs in 4U 1626-67

Outside GCN IAUCs Other ATel on Twitter and Facebook ATELstream ATel Community Site | Post | Search | Policies Credential | Feeds | Email 4 May 2020; 10:40 UT | This space for free for your conference.

# QPOs in 4U 1626-67 ATel #1; J. Kommers (MIT), D. Chakrabarty (MIT), W. H. G. Lewin (MIT) on 17 Dec 1997; 17:28 UT Credential Certification: Jefferson M. Kommers Subjects: X-ray, Binary, Pulsar Tweet The low-mass X-ray binary pulsar 4U 1626-67 shows quasi-periodic oscillations (QPOs) with a centroid frequency of 0.048 Hz and red noise variability as well as coherent pulsations at the 0.130 Hz neutron star rotation frequency. In power density spectra of observations made with the Rossi X-ray Timing Explorer, we have found significant sidebands at the frequencies (n*f_0 - f_qpo) and (n*f_0 + f_qpo), where f_0 = 0.130 Hz is the pulsar spin frequency, f_qpo = 0.048 Hz is the QPO frequency, and n = 1,2,3... is an integer. These sidebands provide a diagnostic of the QPO mechanism. In the 17-30 keV range the powers in the sidebands are symmetric about the harmonic frequencies. This suggests that the instantaneous amplitude of the coherent pulsations is modulated by the QPOs. This phenomenon is expected (for example) in models such as the magnetospheric beat frequency model (MBFM) where the QPOs originate near the polar caps of the neutron star, since any variation in the X-ray emission from the polar caps will affect the intensity of the coherent pulsations. In the 4-8 keV range, however, the lower-frequency sidebands (at n*f_0 - f_qpo) are significantly stronger than their higher-frequency complements (at n*f_0 + f_qpo). Since simple amplitude modulation produces side bands with equal powers, there must be an additional oscillation at the frequencies (n*f_0 - f_qpo) that produces the excess power observed in the enhanced lower-frequency sidebands. In the MBFM there is nothing obvious that would explain the enhanced lower-frequency sidebands. Thus the observed sideband structure is inconsistent with the MBFM being the explanation for the 0.048 Hz QPOs. A scenario that explains the 0.048 Hz QPOs as well as the observed sideband structure is the following. Suppose a coherent structure (a "blob" of some kind) orbits the neutron star with an orbital frequency of 0.048 Hz, which may or may not be a Keplerian frequency (e.g., it may represent a wave packet traveling in the accretion disk). This blob modulates the optical depth along the line of sight as it orbits, producing the 0.048 Hz QPOs. When it crosses the line of sight between the Earth and the neutron star, it attenuates the pulsar beam; this modulates the coherent pulsations at 0.048 Hz and produces the symmetric sidebands. The blob orbits in the same direction as the neutron star rotation, so it reprocesses the pulsar beam at the beat frequencies between the pulsar harmonics and the QPOs (n*f_0 - f_qpo). Some of the reprocessed X-rays are returned along the line of sight, producing the enhanced lower-frequency side bands. Quite independently, we find no evidence that the red noise variability modulates the amplitude of the coherent pulsations. This is also in contrast to the expectations of the MBFM and differs from the behavior in some high-mass X-ray binary pulsars. More information can be found in our manuscript (in preparation), available as a PostScript file at the URL associated with this telegram. PostScript for 1626 manuscript |